Crate kcr_schemas_schemahero_io

Crate kcr_schemas_schemahero_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the schemas.schemahero.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

schemas.schemahero.io/v1alpha4

  • DataType
  • Migration
  • Table

Modules

v1alpha4